@@ -204,10 +204,20 @@ class Plotter:
             # print("Error: One or more of the hue, style, or size variables are not in the data.")
             plt.close()
             return
-
-        for y, l in list(zip(config['y_var'], config['y_var_label'])):
-            sns.lineplot(data=data, x=config['x_var'], y=y, label=l,
-                                hue=config['hue'], style=config['style'], size=config['size'])
+        
+        # Plot the data
+        if config['x_var'] not in config['y_var']:
+            data_m = data.melt(id_vars=[config['x_var']] + [config[k] for k in ['hue', 'style', 'size'] if config[k]],
+                            value_vars=config['y_var'], var_name='variable', value_name='y_val')
+            data_m['variable'].replace(
+                config['y_var'], config['y_var_label'], inplace=True)
+            sns.lineplot(data=data_m, x=config['x_var'], y='y_val', hue='variable', **{k: config[k] for k in [
+                        'style', 'size'] if config[k]})
+        else:
+            for y, l in list(zip(config['y_var'], config['y_var_label'])):
+                plot_kwargs = {k: config[k] for k in [
+                    'hue', 'style', 'size'] if config[k]} or {'label': l}
+                sns.lineplot(data=data, x=config['x_var'], y=y, **plot_kwargs)
         
         if config.get('x_label', None):
             plt.xlabel(config['x_label'])
@@ -225,6 +235,9 @@ class Plotter:
         # Try to set date ticks
         self.try_date_ticks(data, config['x_var'], axis=0)
 
+        # Adjust the padding between and around subplots
+        plt.tight_layout()
+
         # Save the figure if requested
         if save_as:
             plt.savefig(save_as, dpi=dpi)
